/********************************************************************
   TORNADO-PX/DDC4 DCM Demo Utility.
   FLASH Programming (Burn-in) utility. rev.1A
   (C) MicroLAB Systems, 2000


   Description:
   ------------
	This demo utility is used to program (burn-in) user supplied data 
	array into on-board FLASH memory.

	FLASH burn-in data array must be in an include file in 16-bit HEX 
	format and must not exceed the size of DSP on-chip memory (32Kwords). 
	Once data array	has been changed, then this utility must be recompiled 
	using TI C5000 Code Composer compiler and then re-loaded via JTAG 
	emulator and re-run.


   How to create data array to be burned-into on-board FLASH memory
   ----------------------------------------------------------------
    User data array, which is burned into on0board FLASH memory, must be
	in 16-bit C-compatible hex array format and can obtained from
	different user supplied sources. This data array can contain either
	data tables or program code, which can be further boot using 8-bit FLASH
	boot mode.


   Conversion of .OUT file to FLASH burn-in data array and FLASH programming
   -------------------------------------------------------------------------
	The following is the procedure, which can be used to convert C54x
	compiler output file (.OUT) for TORNADO-PX/DDC4 into FLASH burn-in 
	data to be used with this FL_BURN.C demo utility:
		1. Compile your C54x application for TORNADO-PX/DDC4 using
		   -v549 compiler option for TI C5000 CCS tools. Be sure to
		   allocate both C54x program and data memory areas to DSP
		   on-chip memory. Use ROM memory init model for linker. Refer
		   to BL_UART1.C demo sample as an example with BL_UART1.LNK
		   linker command file, which produce BL_UART1.OUT output 
		   C54x executable file.
		2. Convert .OUT file to INTEL HEX boot table format using HEX500.EXE
		   utility from TI C5000 CCS tools. Create command file for
		   HEX500.EXE utility, which contains all required options for
		   conversion to hex-file format. Refer to BL_UART1.H54 command
		   file sample as an example, which converts BL_UART1.OUT input
		   file to BL_UART1.H0 Intel HEX output file.

	  !!! NOTE !!!
	  ------------
		Steps #3 and #4 are MicroLAB specific and can be changed upon 
		the user requirements and environment. The general goal is to 
        convert Intel HEX file, which is generated by HEX500.EXE utility to
		FLASH burn-in C-data array, which will be included during
		compilation of this utility.
		
		3. Convert Intel HEX file to BINARY file using supplied IR.EXE
		   DOS utility from MicroLAB Systems. 

		   When using IR.EXE utility, just used default settings for 
		   LOW/HIGH address selector when loading input INTEL-HEX file 
		   and then specify FILE OUTPUT, ALL BYTES, enter output name, 
		   8000 as LOW address of ROM-zone and default value as HIGH 
		   address of ROM zone.

		   The following is the dialog dump for IR.EXE utility when
		   converting BL_UART1.H0 input Intel-hex file as the demo sample 
		   into BL_UART1.BIN output binary file:

				INTEL-HEX ==> BIN/ROM file  Conversion utility. v.3.1.
				Copyright (C) MicroLAB(tm) Systems Ltd, 1988-1992.  All rights reserved.

				input INTEL-HEX file     : bl_uart1.h0
				LOW-address  of selector : 0
				HIGH-address of selector : ffff

				total blocks read:   138    valid blocks:   137
				    valid address:  MIN = 8000h       MAX = 910Fh

				output bytes selector    : All bytes
				output ROM-file name     : bl_uart1.bin
				LOW-address  of ROM zone : 8000
				HIGH-address of ROM zone : 910f
				write completed OK  ---  : 1110 (hex) bytes written .			

		4. Use BINHEX16.EXE MicroLAB Systems DOS utility and convert binary 
		   output file into FLASH burn-in hex data array for direct 
		   inclusion into this utility code (FL_BURN.C) for further
		   compilation with TI C5000 CCS compiler. 

		   The following is DOS command line for conversion of BL_UART1.BIN 
		   input binary data file to BL_UART1.CI output C-data array file:
				BINHEX16  bl_uart1.bin  bl_uart1.ci

		5. Make sure that FLASH burn-in data array file generated at step #4
		   is included into the code of this FL_BURN.C utility:
				#include "bl_uart1.ci"

		   Compile FL_BURN.C utility using TI C5000 CCS compiler. Be sure
		   that C54x program memory area is allocated either to DPRAM or DSP
		   on-chip RAM, and C54x data memory area is allocated to DSP on-chip
		   RAM only. Refer to FL_BURN.LNK file for more details.

		6. Load FL_BURN.OUT file to C54x DSP environment via JTAG emulator and
		   run the code. 

		   Note, that when running this utility the TORNADO-PX/DDC4 must be 
		   configures in stand-alone mode (SW2-1 must be 'ON'), DSP must be
		   configurd in NO_BOOT mode (SW2-2 must be 'ON'), and FLASH write
		   must be enabled (SW2-3 must be 'ON').
		   
		   If FLASH programming error occurs, then DSP traps to the ERROR label, 
		   otherwise it traps to the HALT_OK label.

		7. Switch off power of TORNADO-PX/DDC4 and configure DSP to FLASH
		   bootmode (SW2-2 must be 'OFF'). Connect external 9600 bauds external
		   terminal  to UART#1 channel. Switch on power for TORNADO-PX/DDC4 and 
		   ensure that all greeting messages and the continuously running 'OK' 
		   message are displayed at external terminal.


   TORNADO platform:
   -----------------
	This demo does not utilize any host TORNADO-PX/DDC4 resources
	and runs in stand-alone mode. MIRAGE JTAG emulator and
	TI CCS tools are required to recompile this demo and to
	upload code to the on-board DSP environment.

  Copyright:
  ----------
	This demo as well as other supplied utilities are distributed free 
	of charge and without any obligation from MicroLAB Systems.


  Demo and Signal Parameters:
  ---------------------------
    on-board configuration switch:
      	- SA-mode
		- no BOOT mode
		- FLASH write is enabled
***********************************************************************/

#include	"math.h"
#include	"c54x_def.h"
#include	"ddc4_dsp.h"	// include general DDC4 C54x defs
#include	"ddc4_dx.h"	// include general DDC4 extension functions


//~~~~~ included FLASH burn-in data array (16-bit C-hex format) ~~~~
#include "bl_uart1.ci"
//~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

// FLASH data array size definition
#define  FLASH_ARRAY_LEN	sizeof(LUI_DATA)

void main()
{  int i;
   unsigned long flash_addr;

    TPXDDC4_init_cpu();

		// erase the chip with verification
	if(TPXDDC4_flash_erase_chip(TPXDDC4_ON)!=0) goto error;

		// now program target array to FLASH 
		// since 8-bit FLASH data are packed into 16-bit words, then 2 cycle is required
    for(flash_addr=0L,i=0;i<FLASH_ARRAY_LEN;i++)
    {
		 if(TPXDDC4_flash_write(flash_addr++,(LUI_DATA[i] & 0xff))!=0) goto error;
		 if(TPXDDC4_flash_write(flash_addr++,((LUI_DATA[i] >>8) & 0xff))!=0) goto error;
    }

		// now verifies written data
    for(flash_addr=0L,i=0;i<FLASH_ARRAY_LEN;i++)
	{

		 if(TPXDDC4_flash_read(flash_addr++)!=(LUI_DATA[i] & 0xff) ) goto error;
		 if(TPXDDC4_flash_read(flash_addr++)!=((LUI_DATA[i] >>8) & 0xff) ) goto error;
  }

halt_ok:
	   /* TRAP here in case programming & verification is OK */
   while(1);	

error:
	   /* TRAP here in case of any error */
   while(1);	


}

